# *** WARNING: this file was generated by the Pulumi Kubernetes codegen tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

from ... import tables, version


class CSIDriver(pulumi.CustomResource):
    """
    CSIDriver captures information about a Container Storage Interface (CSI) volume driver deployed
    on the cluster. CSI drivers do not need to create the CSIDriver object directly. Instead they
    may use the cluster-driver-registrar sidecar container. When deployed with a CSI driver it
    automatically creates a CSIDriver object representing the driver. Kubernetes attach detach
    controller uses this object to determine whether attach is required. Kubelet uses this object to
    determine whether pod information needs to be passed on mount. CSIDriver objects are
    non-namespaced.
    """
    def __init__(self, __name__, __opts__=None, metadata=None, spec=None):
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'storage.k8s.io/v1beta1'
        __props__['kind'] = 'CSIDriver'
        if spec is None:
            raise TypeError('Missing required property spec')
        __props__['spec'] = spec
        __props__['metadata'] = metadata

        if __opts__ is None:
            __opts__ = pulumi.ResourceOptions()
        if __opts__.version is None:
            __opts__.version = version.get_version()

        super(CSIDriver, self).__init__(
            "kubernetes:storage.k8s.io/v1beta1:CSIDriver",
            __name__,
            __props__,
            __opts__)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop
